@@ -5,6 +5,7 @@
  Algorithms for diffusion pathway analysis
 """
 
+import itertools
 from collections import Counter
 
 import numpy as np
@@ -104,7 +105,7 @@ class ProbabilityDensityAnalysis:
         for i, n in count.most_common(ngrid):
             Pr[i] = float(n) / nsteps / len(indices) / lattice.volume * ngrid
 
-        Pr = Pr.reshape(lens[0], lens[1], lens[2])
+        Pr = Pr.reshape(lens[0], lens[1], lens[2])  # pylint: disable=E1121
 
         self.structure = structure
         self.trajectories = trajectories
@@ -226,8 +227,9 @@ class ProbabilityDensityAnalysis:
         """
 
         count = 1
-        VolinAu = self.structure.lattice.volume / 0.5291772083 ** 3
-        symbols = self.structure.symbol_set
+        VolinAu = self.structure.lattice.volume / 0.5291772083**3
+        syms = [site.specie.symbol for site in self.structure]
+        symbols = [a[0] for a in itertools.groupby(syms)]
         natoms = [str(int(self.structure.composition[symbol])) for symbol in symbols]
         init_fcoords = np.array(self.structure.frac_coords)
 
