@@ -8,13 +8,14 @@ RDF implementation.
 from collections import Counter
 from math import ceil
 from multiprocessing import cpu_count
-from typing import List, Tuple, Union, Dict
+from typing import Dict, List, Tuple, Union
 
 import numpy as np
+from joblib import Parallel, delayed
 from scipy.ndimage import gaussian_filter1d
 from scipy.signal import find_peaks
 from scipy.stats import norm
-from joblib import delayed, Parallel
+
 from pymatgen.core import Structure
 from pymatgen.util.plotting import pretty_plot
 
@@ -77,7 +78,7 @@ class RadialDistributionFunction:
         images = images.reshape((len(r) ** 3, 3))
 
         # Find the zero image vector
-        zd = np.sum(images ** 2, axis=1)
+        zd = np.sum(images**2, axis=1)
         indx0 = np.argmin(zd)
 
         for s in structures:
@@ -95,7 +96,7 @@ class RadialDistributionFunction:
         for fcoords, ref_fcoords, latt in zip(fcoords_list, ref_fcoords_list, lattices):
             dcf = fcoords[:, None, None, :] + images[None, None, :, :] - ref_fcoords[None, :, None, :]
             dcc = latt.get_cartesian_coords(dcf)
-            d2 = np.sum(dcc ** 2, axis=3)
+            d2 = np.sum(dcc**2, axis=3)
             dists = [
                 d2[u, v, j] ** 0.5
                 for u in range(len(indices))
@@ -103,13 +104,10 @@ class RadialDistributionFunction:
                 for j in range(len(r) ** 3)
                 if indices[u] != reference_indices[v] or j != indx0
             ]
-            r_indices = [int(dist / dr) for dist in filter(lambda e: e < rmax + 1e-8, dists)]
+            r_indices = [int(dist / dr) for dist in filter(lambda e: e < rmax, dists)]
             dns.update(r_indices)
 
         for indx, dn in dns.most_common(ngrid):
-            if indx > len(interval) - 1:
-                continue
-
             # Volume of the thin shell
             ff = 4.0 / 3.0 * np.pi * (interval[indx + 1] ** 3 - interval[indx] ** 3)
             # print(norm.pdf(interval, interval[indx], sigma) * dn /
@@ -356,7 +354,7 @@ class RadialDistributionFunctionFast:
             for i, j in natoms.items():
                 self.density[s_index][i] = j / self.structures[s_index].volume
 
-        self.volumes = 4.0 * np.pi * self.r ** 2 * self.dr
+        self.volumes = 4.0 * np.pi * self.r**2 * self.dr
         self.volumes[self.volumes < 1e-8] = 1e8  # avoid divide by zero
         self.n_structures = len(self.structures)
         self.sigma = ceil(sigma / self.dr)
@@ -468,7 +466,7 @@ class RadialDistributionFunctionFast:
         if isinstance(species, str):
             species = [species]
         density = [sum(i[j] for j in species) for i in self.density]
-        cn = [np.cumsum(rdf * density[i] * 4.0 * np.pi * self.r ** 2 * self.dr) for i, rdf in enumerate(all_rdf)]
+        cn = [np.cumsum(rdf * density[i] * 4.0 * np.pi * self.r**2 * self.dr) for i, rdf in enumerate(all_rdf)]
         if is_average:
             cn = np.mean(cn, axis=0)
         return self.r, cn
