@@ -4,17 +4,16 @@
 __author__ = "Iek-Heng Chu"
 __date__ = "01/16"
 
-import unittest
-import os
 import json
+import os
+import unittest
 
 import numpy as np
-from pymatgen.analysis.diffusion.aimd.pathway import (
-    ProbabilityDensityAnalysis,
-    SiteOccupancyAnalyzer,
-)
-from pymatgen.analysis.diffusion.analyzer import DiffusionAnalyzer
 from pymatgen.core import Structure
+from pymatgen.io.vasp import Chgcar
+
+from pymatgen.analysis.diffusion.aimd.pathway import ProbabilityDensityAnalysis, SiteOccupancyAnalyzer
+from pymatgen.analysis.diffusion.analyzer import DiffusionAnalyzer
 
 tests_dir = os.path.dirname(os.path.abspath(__file__))
 
@@ -69,6 +68,18 @@ class ProbabilityDensityTest(unittest.TestCase):
         self.assertEqual(s.composition["X"], 50)
         self.assertAlmostEqual(s[177].frac_coords[2], 0.57446809)
 
+    def test_to_chgcar(self):
+        file = os.path.join(tests_dir, "cNa3PS4_pda.json")
+        data = json.load(open(file))
+        diff_analyzer = DiffusionAnalyzer.from_dict(data)
+
+        # ProbabilityDensityAnalysis object
+        pda = ProbabilityDensityAnalysis.from_diffusion_analyzer(diffusion_analyzer=diff_analyzer, interval=0.1)
+        pda.to_chgcar("CHGCAR.PDA")
+        chgcar = Chgcar.from_file("CHGCAR.PDA")
+        self.assertEqual(pda.structure.species, chgcar.structure.species)
+        os.remove("CHGCAR.PDA")
+
 
 class SiteOccupancyTest(unittest.TestCase):
     def test_site_occupancy(self):
