@@ -24,11 +24,7 @@ import warnings
 import numpy as np
 import scipy.constants as const
 from monty.json import MSONable
-
-from pymatgen.analysis.structure_matcher import (
-    OrderDisorderElementComparator,
-    StructureMatcher,
-)
+from pymatgen.analysis.structure_matcher import OrderDisorderElementComparator, StructureMatcher
 from pymatgen.core.periodic_table import get_el_sp
 from pymatgen.core.structure import Structure
 from pymatgen.io.vasp.outputs import Vasprun
@@ -269,7 +265,7 @@ class DiffusionAnalyzer(MSONable):
                     dcomponents = dc[:, n:, :] - dc[:, :-n, :]
 
                 # Get msd
-                sq_disp = dx ** 2
+                sq_disp = dx**2
                 sq_disp_ions[:, i] = np.average(np.sum(sq_disp, axis=2), axis=1)
                 msd[i] = np.average(sq_disp_ions[:, i][indices])
 
@@ -335,7 +331,7 @@ class DiffusionAnalyzer(MSONable):
             # Drift and displacement information.
             self.drift = drift
             self.corrected_displacements = dc
-            self.max_ion_displacements = np.max(np.sum(dc ** 2, axis=-1) ** 0.5, axis=1)
+            self.max_ion_displacements = np.max(np.sum(dc**2, axis=-1) ** 0.5, axis=1)
             self.max_framework_displacement = np.max(self.max_ion_displacements[framework_indices])
             self.msd = msd
             self.mscd = mscd
@@ -493,7 +489,7 @@ class DiffusionAnalyzer(MSONable):
             for sp in sorted(self.structure.composition.keys()):
                 indices = [i for i, site in enumerate(self.structure) if site.specie == sp]
                 sd = np.average(self.sq_disp_ions[indices, :], axis=0)
-                plt.plot(plot_dt, sd, label=sp.__str__())
+                plt.plot(plot_dt, sd, label=str(sp))
             plt.legend(loc=2, prop={"size": 20})
         elif mode == "sites":
             for i, site in enumerate(self.structure):
@@ -802,7 +798,7 @@ def get_conversion_factor(structure, species, temperature):
     n = structure.composition[species]
 
     vol = structure.volume * 1e-24  # units cm^3
-    return 1000 * n / (vol * const.N_A) * z ** 2 * (const.N_A * const.e) ** 2 / (const.R * temperature)
+    return 1000 * n / (vol * const.N_A) * z**2 * (const.N_A * const.e) ** 2 / (const.R * temperature)
 
 
 def _get_vasprun(args):
@@ -847,7 +843,7 @@ def get_extrapolated_diffusivity(temps, diffusivities, new_temp):
         new_temp (float): desired temperature. units: K
 
     Returns:
-        (float) Diffusivity at extrapolated temp in mS/cm.
+        (float) Diffusivity at extrapolated temp in cm^2/s.
     """
     Ea, c, _ = fit_arrhenius(temps, diffusivities)
     return c * np.exp(-Ea / (const.k / const.e * new_temp))
